package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcAssessContent;
import com.ruoyi.oa.service.ICmcAssessContentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考核内容Controller
 * 
 * @author cmc
 * @date 2024-01-09
 */
@RestController
@RequestMapping("/oa/assessContent")
public class CmcAssessContentController extends BaseController
{
    @Autowired
    private ICmcAssessContentService cmcAssessContentService;

    /**
     * 查询考核内容列表
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmcAssessContent cmcAssessContent)
    {
        startPage();
        List<CmcAssessContent> list = cmcAssessContentService.selectCmcAssessContentList(cmcAssessContent);
        return getDataTable(list);
    }

    /**
     * 导出考核内容列表
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:export')")
    @Log(title = "考核内容", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcAssessContent cmcAssessContent)
    {
        List<CmcAssessContent> list = cmcAssessContentService.selectCmcAssessContentList(cmcAssessContent);
        ExcelUtil<CmcAssessContent> util = new ExcelUtil<CmcAssessContent>(CmcAssessContent.class);
        util.exportExcel(response, list, "考核内容数据");
    }

    /**
     * 获取考核内容详细信息
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:query')")
    @GetMapping(value = "/{contentId}")
    public AjaxResult getInfo(@PathVariable("contentId") String contentId)
    {
        return success(cmcAssessContentService.selectCmcAssessContentByContentId(contentId));
    }

    /**
     * 新增考核内容
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:add')")
    @Log(title = "考核内容", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcAssessContent cmcAssessContent)
    {
        return toAjax(cmcAssessContentService.insertCmcAssessContent(cmcAssessContent));
    }

    /**
     * 修改考核内容
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:edit')")
    @Log(title = "考核内容", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcAssessContent cmcAssessContent)
    {
        return toAjax(cmcAssessContentService.updateCmcAssessContent(cmcAssessContent));
    }

    /**
     * 删除考核内容
     */
    @PreAuthorize("@ss.hasPermi('oa:assessContent:remove')")
    @Log(title = "考核内容", businessType = BusinessType.DELETE)
	@DeleteMapping("/{contentIds}")
    public AjaxResult remove(@PathVariable String[] contentIds)
    {
        return toAjax(cmcAssessContentService.deleteCmcAssessContentByContentIds(contentIds));
    }
}
